@@ -1,9 +1,3 @@
-# Author: Oscar Perpinan Lamigueiro oscar.perpinan@upm.es
-# Date :  August 2012
-# Version 0.11
-# Licence GPL v3
-
-##xyplot for directions created with xyLayer
 setGeneric('hexbinplot')
 
 setMethod('hexbinplot', signature(x='formula', data='Raster'),
@@ -13,9 +7,8 @@ setMethod('hexbinplot', signature(x='formula', data='Raster'),
             par.settings=rasterTheme(),
             ...){
             idx=getZ(data)
-            ## names replace layerNames with raster version 2.0-04
-            rasterVersion <- as.character(packageVersion('raster'))
-            nms <- if (compareVersion(rasterVersion, '2.0-04') == -1) layerNames(data) else names(data)
+
+            nms <- names(data)
 
             nl <- nlayers(data)
             xLayer <- getValues(init(data, v='x'))
